# HL Chemistry - A

The course code for this page is **SCH3UZ**.

## 1.1 - Review and base knowledge

### Binary ionic and molecular compound nomenclature

An **ionic bond** is a bond formed between a metal cation and a non-metal anion. The compound name is written as the cation followed by the anion with the "-ide" ending. If the cation is multivalent (all transition metals aside from $\text{Si}$ and $\text{Co}$), the charge of the cation should be written in parentheses in roman numerals between the two ions.
$$\text{cation anion-ide || cation (roman charge) anion-ide}$$

!!! example
    - $\text{NaCl}$: sodium chloride
    - $\text{Al}_2\text{O}_3$: aluminium oxide
    - $\text{CuO}$: copper (II) oxide
    - $\text{Cu}_2\text{O}$: copper (I) oxide

A **covalent bond** is a bond formed between two non-metals. The compound name is written as the non-metal that appears first followed by the non-metal that appears second with the -ide ending, prefixing both with Greek prefixes to represent the number of atoms of that element. If there is only one atom of the first element, or if it would be unambiguous otherwise, "mono" is excluded for that element. The final vowel of the prefix is excluded if it ends with a vowel and the element following it starts with a vowel, except for the letter "i".
$$\text{prefix–element prefix–element–ide}$$

!!! example
    - $\text{N}_2\text{O}_5$: dinitrogen pentoxide
    - $\text{CO}$: carbon monoxide
    - $\text{PI}_3$: phosphorous triiodide.
    - $\text{HCl}$: hydrogen chloride

!!! warning
    The following common molecular compounds do not follow the rules above and have the following names instead:
    
    - $\text{H}_2\text{O}_2$: hydrogen peroxide
    - $\text{O}_3$: ozone
    - $\text{H}_2\text{O}_\text{(l)}$: water
    - $\text{CH}_4$: methane
    - $\text{NH}_3$: ammonia

### Polyatomic ions

A polyatomic ion consists of an element covalently bonded to oxygen atoms, ending up with a non-neutral charge. The parent form of these compounds is written as the non-oxygen element with the "-ate" suffix.
$$\text{element–ate}$$

!!! example
    - $\text{CO}_3 {}^{2-}$: carbonate
    - $\text{NO}_3 {}^-$: nitrate

However, the number of oxygen atoms in the ion can change while the **charge remains the same**. In this case, the following prefixes and suffixes are applied based on the difference in oxygen atoms from its parent:

 - +1 $\text{O}$: per…ate
 - +0 $\text{O}$: …ate
 - -1 $\text{O}$: …ite
 - -2 $\text{O}$: hypo…ite

Polyatomic ions in the **same group** on the periodic table form similar polyatomic ions.

!!! example
    Chlorate ($\text{ClO}_3{}^-$) and bromate ($\text{BrO}_3{}^-$) have the same base forms and thus the same extended forms.

To remember the charges and number of oxygen atoms in **some** polyatomic ions, the below mnemonic can be used:
$$\text{Nick Borate the Camel had a Clam Supper in Phoenix}$$

The first letter(s) of each capitalised word is the non-oxygen component, the number of consonants in that word is equal to the number of oxygen atoms, and the number of vowels indicates its charge.

Alternatively/complimentarily, memorise the following table:

| Name | Formula | Name | Formula |
| --- | --- | --- | --- |
| Ammonium | $\text{NH}_4{}^+$ | Sulfate | $\text{SO}_4{}^{2-}$ |
| Hydroxide | $\text{OH}^-$ | Chlorate | $\text{ClO}_3{}^-$ |
| Cyanide | $\text{CN}^-$ | Chromate | $\text{CrO}_4{}^-$ |
| Borate | $\text{BO}_3{}^{3-}$ | Dichromate | $\text{Cr}_2\text{O}_7{}^{2-}$ |
| Carbonate | $\text{CO}_3{}^{2-}$ | Permanganate | $\text{MnO}_4{}^-$ 
| Nitrate | $\text{NO}_3{}^-$ | Acetate | $\text{CH}_3\text{COO}^-$ |
| Phosphate | $\text{PO}_4{}^{3-}$ | | |

Hydrogen ions can be added to polyatomic ions, reducing the compound's negative charge by 1. "Hydrogen" is prefixed with its Greek numerical prefix (except "mono", usually) and placed before the oxyanion until the compound becomes an acid.

!!! example
    - $\text{HPO}_4{}^{2-}$: hydrogen phosphate
    - $\text{H}_2\text{PO}_3{}^{-}$: dihydrogen phosphite

### Acids

All acids must be **aqueous**.

A **binary acid** consists of hydrogen atoms bonded to exactly one other non-metal element **dissolved in water**. If the compound begins with a hydrogen atom but *is not aqueous*, it is a binary covalent molecule. Binary acids are written as their non-metal element prefixed by "hydro-" and suffixed with "-ic acid".
$$\text{hydro–element–ic acid}$$

!!! example
    - $\text{HCl}_\text{(aq)}$: hydrochloric acid
    - $\text{HCl}$: hydrogen chloride
    - $\text{H}_2\text{S}_\text{(aq)}$: hydrosulfuric acid

An **oxyacid** consists of a polyatomic ion bonded to hydrogen ions equal to its charge. As their chemical structure can only exist while aqueous, $\text{(aq)}$ is not required. Oxyacids are written as per their polyatomic ion with "-ate" replaced with "-ic", "-ite" replaced with "-ous", and with the suffix "acid".
$$\text{prefix-element-suffix acid}$$

!!! example
    - $\text{H}_2\text{CO}_3$: carbonic acid
    - $\text{HIO}_4$: periodic acid
    - $\text{HIO}_3$: iodic acid
    - $\text{HClO}_2$: chlorous acid
    - $\text{HClO}$: hypochlorous acid

### Bases

There are two types of bases in this course:

 - Hydroxides ($\text{OH}^-$)
 - Ammonia ($\text{NH}_3$)

### Hydrates

Hydrates are ionic compounds with water associated with them, but the water molecules are held loosely and are not actually part of the compound. There is a specific number of water molecules per formula unit of ionic compound, so the formula is written as exactly one of the ionic compound followed by a dot and $\text{H}_2\text{O}$ with a coefficient denoting the number of water molecules associated with the salt. Hydrates are named as per their ionic compound followed by "hydrate" with Greek prefixes.
$$\text{ion} \bullet x\text{H}_2\text{O}$$

!!! example
    $\text{Na}_3\text{PO}_3 \bullet 4\text{H}_2\text{O}$: sodium phosphite tetrahydrate

Ionic compounds that have water are **hydrated**. Those that do not are **anhydrous**.

### Types of reactions

#### Synthesis

A synthesis reaction involves the combination of smaller atoms or molecules to form **larger** molecules.
$$A + B → AB$$

!!! example
    - $2\text{H}_\text{2 (g)} + \text{O}_\text{2 (g)} → 2\text{H}_2\text{O}_\text{(g)}$
    - $\text{HCl}_\text{(g)} + \text{NH}_\text{3 (g)} → \text{NH}_4\text{Cl}_\text{(aq)}$

!!! warning
    **Metal oxides** react with water to form bases while **non-metal oxides** form acids.

#### Decomposition

A decomposition reaction involves splitting a larger molecule into smaller molecules or elements.
$$AB → A + B$$

!!! example
    - $2\text{H}_2\text{O}_\text{(l)} → 2\text{H}_\text{2 (g)} + \text{O}_\text{2 (g)}$
    - $\text{CaCO}_\text{3 (s)} → \text{CaO}_\text{(s)} + \text{CO}_\text{2 (g)}$

!!! warning
    **Carbonic acid** and **ammonium hydroxide** decompose when formed as products of other reactions, so the results of this decomposition need to be considered (e.g., checking if double dispalcement reactions occur).
    $$\text{H}_2\text{CO}_\text{3 (aq)} → \text{H}_2\text{O}_\text{(l)} + \text{CO}_\text{2 (g)}$$
    $$\text{NH}_4\text{OH}_\text{(aq)} → \text{NH}_\text{3 (g)} + \text{H}_2\text{O}_\text{(l)}$$

#### Combustion

A combustion reaction involves the **rapid** reaction of a substance with **oxygen** to produce oxides and **heat**.
$$A + \text{O}_\text{2 (g)} → \text{oxide}$$

!!! example
    $2\text{Mg}_\text{(s)} + \text{O}_\text{2 (g)} → 2\text{MgO}_\text{(s)}$

!!! warning
    Combustion reactions must be *rapid*. This means that reactions such as that of iron with oxygen gas to form iron oxide (rusting) are *not* combustion reactions.

When combusting hydrocarbons, the quantity of oxygen present determines if the combustion will be **complete** or **incomplete**. The only products of complete combustion are carbon dioxide and water, while the products of incomplete combustion can also include carbon monoxide and carbon.
$$\text{C}_x\text{H}_y + \text{O}_\text{2 (g)} → \text{CO}_\text{2 (g)} + \text{H}_2\text{O} + \text{CO}_\text{(g)} + \text{C}_\text{(s)}$$

!!! example
    - Complete: $\text{C}\text{H}_4 + 2\text{O}_\text{2 (g)} → \text{CO}_2 + 2\text{H}_2\text{O}$
    - Incomplete: $\text{C}\text{H}_4 + \text{O}_\text{2 (g)} → \text{C} + 2\text{H}_2\text{O}$

#### Single displacement

A single displacement reaction involves a **more reactive** element reacting with a compound such that it displaces the **less reactive** element in the compound of the same type (metals + hydrogen or non-metals). The **activity series** is used to identify if a single displacement reaction takes place.

If $A$ is a metal:
$$A + BC → AC + B$$

If $A$ is a non-metal:
$$A + BC → BA + C$$

!!! note
    - The elemental forms of all metals are monatomic (just one atom) and are solids are room temperature, except for $\text{Hg}_\text{(l)}$.
    - The elemental forms of phosphorus and sulfur are $\text{P}_4$ and $\text{S}_8$, respectively.
    - The "-gens" (hydrogen, nitrogen, oxygen, halogens) are all diatomic in their elemental form.

!!! example
    - $\text{Zn}_\text{(s)} + 2\text{HCl}_\text{(aq)} → \text{ZnCl}_\text{2 (aq)} + \text{H}_\text{2 (g)}$
    - $\text{Cl}_\text{2 (g)} + 2\text{NaBr}_\text{(aq)} → \text{Br}_\text{2 (g)} + 2\text{NaCl}_\text{(aq)}$
    - $\text{Cu}_\text{(s)} + 2\text{AgNO}_\text{3 (aq)} → \text{Cu(NO}_3)_\text{2 (aq)} + 2\text{Ag}_\text{(s)}$

#### Double displacement

A double displacement reaction involves two compounds "exchanging" their components to form two new compounds. It can **only occur** if either a precipitate, a salt and water, or a gas and water are formed. Otherwise, there is **no reaction**.

$$AB + CD → AD + BC$$

To predict if a precipitate will form, a solubility table or the following solubility rules can be used (the insoluble compound is the precipitate):

 - All nitrates are soluble
 - All alkali metals are soluble
 - Ammonium is soluble

!!! example
    $\text{BaCl}_\text{2 (aq)} + \text{K}_2\text{SO}_\text{4 (aq)} → 2\text{KCl}_\text{(aq)} + \text{BaSO}_\text{4 (s)}$

To predict if a salt and water will form, the two factors must be an acid and a base.

!!! example
    $3\text{NaOH}_\text{(aq)} + \text{H}_3\text{PO}_\text{4 (aq)} → \text{Na}_3\text{PO}_\text{4 (aq)} + 3\text{H}_2\text{O}_\text{(l)}$

To predict if a gas and water will form, either carbonic acid or ammonium hydroxide must be formed after the double displacement reaction as those two compounds will decompose.

!!! example
    $\text{MgCO}_\text{3 (s)} + 2\text{HCl}_\text{(aq)} → \text{CO}_\text{2 (g)} + \text{H}_2\text{O}_\text{(l)} + \text{MgCl}_\text{2 (aq)}$

### Total and net ionic equations
A total ionic equation shows the **dissociation** (separation) of soluble ionic compounds into their respective ions as well as reactants and products. Each ion is shown separately, so coefficients are used if there is more than one of that ion.

!!! example
    $\text{Na}_2\text{SO}_\text{4 (aq)} + \text{CaCl}_\text{2 (aq)} → \text{CaSO}_\text{4 (s)} + 2\text{NaCl}_\text{(aq)}$ <br>
    Total ionic equation: $2\text{Na}^+{}_\text{(aq)} + \text{SO}_4{}^{2-}{}_\text{(aq)} + \text{Ca}^{2+}{}_\text{(aq)} + 2\text{Cl}^-{}_\text{(aq)} → \text{CaSO}_\text{4 (s)} + 2\text{Na}^+{}_\text{(aq)} + 2\text{Cl}^-{}_\text{(aq)}$

A net ionic equation is similar to a total ionic equation but only shows the ions involved in the chemical reaction by eliminating all ions that do not participate in the reaction (are the same on both sides), or **spectator ions**.

!!! example
    $\text{SO}_4{}^{2-}{}_\text{(aq)} + \text{Ca}^{2+}{}_\text{(aq)} → \text{CaSO}_{4 (s)}$

If there is no reaction, there is no net ionic equation but there is a total ionic equation.

## 2.1 - Atoms

!!! definition
    - The **effective nuclear charge** ($Z_\text{eff}$) is the net positive charge (attraction to the nucleus) experienced by an electron in an atom.
    - **Electron shielding** is decrease in the effective nuclear charge of an electron because of the repulsion of other electrons in lower-energy shells.

**Atomic notation** is used to represent individual atoms or ions. It is written in the form $^M_Z \text{Symbol}^\text{Charge}$, where $M$ is the mass number of the particle and $Z$ is the atomic number of the particle.

!!! example
    - $^1_1 \text{H}^{+}$ is the atomic notation for the most common hydrogen ion.
    - $^{16}_8 \text{O}^{2-}$ is the atomic notation for the most common oxygen ion.
    - $^{20}_{10} \text{Ne}$ is the atomic notation for the most common neon atom.

### Isotopes

Isotopes are atoms of the same element but with different masses, or alternatively, atoms with the same number of protons but with different numbers of neutrons.

**Radioisotopes** are isotopes that are unstable (will spontaneously decay, are radioactive). Unstable atoms **decay** (break down) into one or more different isotopes of a different element. The **half-life** of a radioisotope is the time it takes for 50% of a sample's atoms to decay.

!!! warning
    Radioisotopes are dangerous! They emit radiation, which is not at all good for human health in the vast majority of cases. However, there are also useful applications for radioisotopes today. For example, Cobalt-60 is used in radiation therapy to kill cancer tumours by damaging their DNA.

### Atomic mass

The mass of every atom is represented relative to 1/12th of a carbon-12 atom. This mass is either unitless or expressed in terms of **atomic mass units (amu or u)**. On the periodic table, the **relative atomic mass** ($A_r$) is shown, which is the sum of the masses of each isotope combined with their natural abundance (%abundance).

$$A_r = \text{%abundance}×\text{mass number of isotope}$$
$$m_a = \Sigma A_r$$

When calculating the atomic mass from the graph from a **mass spectrometer**, the sum of the natural abundances of each isotope may not equal 100 or 1 (not in %abundance). In this case, calculation of %abundance will need to be done before solving for $m_a$.

A mass spectrometer may also provide mass in the form of $M/Z$, which represents mass over charge. For the sake of simplicity, $Z=1$, so $M/Z$ represents the mass of a particle.

### Atomic radius

The atomic radius of an atom is the distance from the centre of the nucleus to approximately the outer boundary of the electron shell. This cannot be directly measured by scientists.

### Ionisation energy

The first ionisation energy of an element is the minimum amount of energy required to remove one mole of electrons from one mole of *gaseous* atoms to form a mole of gaseous ions, so that
$$\text{Q}_\text{(g)} \rightarrow \text{Q}_\text{(g)}^+ + \text{e}^-$$

Any subsequent ionisation energies of an element are the minimum amount of energy required to remove one *additional* mole of electrons. For example, the second ionisation energy would involve
$$\text{Q}_\text{(g)}^+ \rightarrow \text{Q}_\text{(g)}^{2+} + \text{e}^-$$

It requires vastly more energy to remove an electron from a filled valence shell compared to an unfilled valence shell.

### Electron affinity

The electron affinity of an atom is the amount of energy **required** or **released** to *add* an electron to a neutral *gaseous* atom to form a negative ion, such that
$$\text{Q}_\text{(g)} + \text{e}^- \rightarrow \text{Q}^-_\text{(g)}$$ 

If energy is released, the atom has a **negative** electron affinity, and will form a stable ion.

If energy is required, the atom has a **positive** electron affinity, and will form an unstable ion (the ion will spontaneously decay).

### Electronegativity

The electronegativity of an atom represents the ability of that atom to attract a pair of electrons in a **covalent bond**. It ranges from $0$ to $4$ on the Pauling scale. As electronegativity increases, the atom more strongly holds on to the electrons in its covalent bond, so the pair of electrons in that bond spend more time around the atom with the higher electronegativity.

### Reactivity

The reactivity of an element is how "willing" it is to give up or gain electrons to fill its valence shell.

The reaction of an **alkali metal** with water always forms a hydroxide and hydrogen gas. For example, lithium reacts with water such that:
$$2\text{Li}_\text{(s)} + 2\text{H}_2\text{O}_\text{(l)} \rightarrow 2\text{LiOH}_\text{(aq)} + \text{H}_{2 (g)}$$

The reaction of a **halogen** with hydrogen gas always forms a hydride. For example, fluorine reacts with hydrogen gas such that:
$$\text{Fl}_\text{(g)} + \text{H}_\text{2 (g)} \rightarrow 2\text{HFl}_\text{(g)}$$

## 2.2 - Electrons in atoms

### The electromagnetic spectrum

**Electromagnetic radiation** is energy that travels in oscillating waves at the speed of light, having both an electric and a magnetic field.

!!! reminder
    $c$ is the standard symbol for the speed of light in a vacuum (~$3×10^8$ m/s).

**Wavelength ($\lambda$)** is the distance between two identical areas on the pattern of the wave (e.g., crest to crest), and is measured in **nanometres**. The **frequency ($f$)** of a wave is the number of times it oscillates in a second, and is measured in **hertz**.

The wavelength and frequency of a wave are inversely proportional, and the more energy of electromagnetic radiation, the smaller the frequency, and vice versa.

$$\lambda f = c$$

The visible spectrum contains all of the wavelengths that the human eye can detect, and ranges from **400 to 700 nm**.

<img src="/resources/images/em-spectrum.png" width=700>(Source: Kognity)</img>

### Continuous and line spectra

A **continuous** spectrum shows all wavelengths in a particular range or region, while line spectra have gaps between a particular range.

There are two types of line spectra: **absorption** line spectra and **emission** line spectra. For a given element, all lines will be in the same position as the two spectra are two different ways of representing the same data.

<img src="/resources/images/spectra.png" width=700>(Source: Kognity)</img>

To create an absorption line spectrum, white light is shone on the element and reflected and the resulting spectrum is captured.

To create an emission line spectrum, a different type of energy, typically electricity, is forced on the element. Atoms re-emit this energy in the form of electromagnetic radiation and the resulting spectrum is captured.

In both cases, a slit to focus the beam and a prism to separate the wavelengths are used.

### Line spectra but complicated

When an atom is **excited** (energy is added), its electrons absorb it and become excited and transition to higher energy levels. As they fall back down to lower energy levels, the transitions are accompanied by an **emission** of energy.

**Absorption** line spectra are produced when electrons absorb energy and move to higher energy levels, while **emission** line spectra are produced when electrons release energy.

!!! definition
    - An **energy level** is a possible area where electrons can occupy and is synonymous with "shell".
    - The **ground state** of an electron is its energy level if no energy is added.

**Energy level diagrams** can be used to demonstrate this movement. The lines get closer together, or converge, as energy level increases, similar to the spectra.

!!! example
    The below line spectra and energy level diagrams are representative of the formation visible light absorption/emission spectrum for hydrogen.

<img src="/resources/images/h-low-to-high.png" width=700>(Source: Kognity)</img>
<img src="/resources/images/h-high-to-low.png" width=700>(Source: Kognity)</img>

As electrons move **down** energy levels, they emit,

 - ultraviolet light if they move down to $n=1$
 - visible light if they move down to $n=2$ (the wavelength depends on the quantity of emitted energy)
 - infrared light if they move down to $n=3$

!!! warning
    Electrons may not directly move down to their original energy levels. To form the full line spectra of hydrogen, some electrons transition to energy levels above 2 and then eventually go down to $n=2$.

### Convergence and first ionisation energy

At higher energy levels, the distance between each consecutive energy level becomes smaller until there is no change at all. This highest line is known as the **convergence limit**, and is known as $n=∞$. Electrons in the $n=∞$ energy level are no longer attracted by the nucleus, resulting in the formation of a positve ion. The energy required for this can be calculated using the following equation, where $E$ is energy required in joules, $h$ is Planck's constant:
$$E=\text{convergence limit} · h$$

To find the first ionisation energy of an element, the amount of energy required is equal to the difference in frequency of the **ground state** of the first valence electron and $n=∞$ multiplied by Planck's constant. This returns the first ionisation energy of one atom, or in electronvolts (eV).

To find the convergence limit **graphically**, graph the difference of frequencies in the spectrum ($\Delta f$) against each each frequency ($f$) and extrapolate to $\Delta f=0$.

### Schrödinger model

According to **Heisenberg's uncertainty principle**, the more precisely the position of an electron is known, the less precisely its momentum is known and vice versa. Since the Bohr-Rutherford model, like most models, is an egregious lie, this principle is used to develop the Schrödinger model.

The Schrödinger model asserts that electrons are now **three-dimensional waveforms** instead of particles and relates the wave to the electron's energy and position. As such, the position of each electron is represented as a **3D probability cloud** around the nucleus, also known as an **orbital**.

### Orbitals

Orbitals have different shapes, sizes, and distances from the nucleus. Each main energy level has one or more orbitals depending the maximum number of electrons in the energy level. Each orbital can contain **up to 2** electrons and is associated with a specific region of space in the atom. The electrons contained in the orbital may be found anywhere in that space.

The four types of orbitals currently known are: *s*, *p*, *d*, and *f*.

The group of orbitals of the same type in the same energy level are known as the **sublevel** of that type. A coefficient is given to indicate the energy level of that sublevel.

!!! example
    The *p* sublevel consists of 3 *p*-orbitals at a given energy level. The *p* sublevel of energy level 2 is written as **2*****p***.

| Main energy level | Types of orbitals | Number of orbitals | Maximum number of electrons |
| --- | --- | --- | --- |
| $n=1$ | 1 *s* | 1 | 2 |
| $n=2$ | 1 *s*, 3 *p* | 4 | 8 |
| $n=3$ | 1 *s*, 3 *p*, 5 *d* | 9 | 18 |
| $n=4$ | 1 *s*, 3 *p*, 5 *d*, 7 *f* | 16 | 32 |
| $n$ | | $n^2$ | $2n^2$ |

Orbitals of the same type but in higher energy levels are simply larger, so any electrons in the higher energy level may be found in those lower orbitals (and maybe even in the space of other orbital types, too). However, electrons already occupying the other orbitals repel the higher electrons, causing them to spend *on average* more time in their orbital, outside of lower ones.

<img src="/resources/images/s-p-orbitals.png" width=700>(Source: Kognity)</img>

*s*-orbitals are spherical in shape and are centred on the nucleus. There is one on each energy level.

*p*-orbitals are dumbbell-shaped and centred on the nucleus. Each orbital is aligned on a different axis. There are three on each energy level starting from $n=2$.

*d*-orbitals have complex shapes. There are 5 in each energy level starting from $n=3$.

*f*-orbitals have more complex shapes. There are 7 in each energy level starting from $n=4$.

The **Aufbau principle** states that orbitals are filled up in order of increasing energy, which is shown in the image below.

<img src="/resources/images/orbital-energy.png" width=700>(Source: Kognity)</img>

### Orbital box diagrams

According to **Hund's rule**, atoms fill all orbitals in the same sublevel before pairing up, similar to *Monopoly* house-building rules.

## 3 - Periodicity

### Models

Please see [SL Physics#Models](/sph3u7/#models) for more information.

### Periodic trends

Some trends in the periodic table include:

 - atomic radius decreases when going across a period and increases when going down a group
 - ionic radius decreases when going across a period for groups 1–13, then sharply increases and then increases for groups 15–17; it increases when going down a group
 - electron affinity increases when going across a period and decreases when going down a group
 - ionisation energy increases when going across a period and decreases when going down a group
 - electronegativity increases when going across a period and decreases when going down a group
 - reactivity of alkali metals increases when going down the group
 - reactivity of halogens decreases when going down the group

When explaining these trends in the periodic table, it is best to use the following basic concepts to build on to larger points.

Across a period, the number of shells occupied by the electrons is the same but the number of protons in the nucleus increases. Therefore,

 - the attraction of each electron to the nucleus (effective nuclear charge) increases as the number of protons increases
 - shielding is unchanged as the number of electrons between the valence electrons and the nucleus is the same

Down a period, the number of shells occupied by the electrons increases, so valence electrons are further from the nucleus. Therefore,

 - the attraction of valence electrons to the nucleus decreases due to the increasing distance
 - shielding increases due to the increasing number of electrons between the valence electrons and the nucleus

!!! example
    To explain why there is a trend of decreasing atomic radius across a period:

    - As the number of protons and electrons increase together, but the number of electron shells does not change, the effect of shielding remains unchanged while effective nuclear charge increases.
    - This increased attraction to the nucleus reduces the atomic radius compared to other atoms before it.

### Period 3 oxides

Metal oxides (oxides of $\text{Na}$ to $\text{Al}$) all form "giant ionic lattices" (alternatively just "lattices") as an ionic bond is formed between a metal and a non-metal. These are typically solids because of their strong **electrostatic attraction**.

Metal oxides, except silicon (oxides of $\text{P}$ to $\text{Cl}$) all form molecular compounds that exist as individual molecules as a covalent bond is formed between two non-metals. These are typically liquids or gases because of their weak **intermolecular forces**.

Period 3 oxides start basic but become more acidic when going across the period, with aluminium oxide being the turning point as an **amphoteric** substance (can be both an acid or a base). Basic oxides dissolve in water to form hydroxides while acidic oxides dissolve in water to form their respective oxyacids.

!!! example
    The following equations should be known by heart and are examples of period 3 oxides reacting with water.
    $$
    \text{Na}_2\text{O}_\text{(s)} + \text{H}_2\text{O}_\text{(l)} → 2\text{NaOH}_\text{(aq)} \\
    \text{MgO}_\text{(s)} + \text{H}_2\text{O}_\text{(l)} → \text{Mg(OH)}_\text{2 (aq)} \\
    \text{P}_4\text{O}_\text{10 (s)} + 6\text{H}_2\text{O}_\text{(l)} → 4\text{H}_3\text{PO}_\text{4 (aq)} \\
    \text{SO}_\text{3 (g)} + \text{H}_2\text{O}_\text{(l)} → \text{H}_2\text{SO}_\text{4 (aq)} \\
    3\text{NO}_\text{2 (g)} + \text{H}_2\text{O}_\text{(l)} → 2\text{HNO}_\text{3 (aq)} + \text{NO}_\text{(g)}
    $$

### Alkali metals and halogens

The alkali metals are a family of highly reactive metals in group 1. They are very soft, and their melting and boiling points are relatively low, decreasing more when going down the group due to their weaker attraction. When reacted with water, they form **hydrogen gas and metal hydroxides** that have a high pH, hence the name "alkali" metals.

The halogens are a family of highly reactive non-metals in group 17. They occur diatomically (in molecules composed of two of the same element) and start as gases but become solids when going down the group due to stronger intermolecular forces. A single displacement reaction involving halogens only occurs if the more reactive halogen is not already bonded to the cation. Halogens are also very strong oxidising agents with their effectiveness increasing going up the group.

## 4.0 - Chemical bonding and structure

A chemical bond consists of the strong electronic interactions of the **valence** electrons between atoms that hold the atoms closer together. This only occurs if the atoms would reduce their potential energy by bonding.

!!! reminder
    When drawing a Lewis **dot diagram**, covalent bonds must be represented as two adjacent dots. When drawing a Lewis **structure**, covalent bonds must be represented as lines connecting the atoms. 

    If the process stage is required:

    - Electrons destined to be shared must be encircled.
    - Electrons to be transferred must have arrows pointing to their destination.
    - x'es are used to represent additional electrons that have an unknown source.

### Percentage ionic character

Bonding is a spectrum. The percentage ionic character of a chemical bond shows roughly the amount of time valence electrons spend near an atom or ion in a bond. The difference between two elements' electronegativity (ΔEN) indicates how covalent and how ionic the bond **behaves**.

If ΔEN is:

 - less than 0.5, it behaves like a **pure covalent** bond
 - between 0.5 and 1.7, it behaves like a **polar covalent** bond
 - greater than 1.7, it behaves like an **ionic** bond

## 4.1 - Ionic bonding and structure

An ionic bond is the electrostatic attraction between oppositely charged **ions**. Electrons are transferred first, and then the bond forms via the attraction of the now-positive and negative ions. This reduces the potential energy of the ions and therefore increases their stability.

!!! definition
    **Electrostatic attraction** is the force of attraction between opposite charges.

!!! warning
    When expressing ionic bonds in a Lewis dot diagram, ions with charges of the same sign must *never* be placed next to one another.

### Structure of ionic compounds

Ionic compounds are composed of a **lattice structure** (crystalline structure) of ions of alternating charges. A **formula unit** is the lowest ratio of positive to negative ions.

<img src="/resources/images/nacl-lattice.jpeg" width=700>(Source: Kognity)</img>

!!! example
    In sodium chloride, the ratio of positive sodium ions to negative chloride ions is always 1:1, so its formula is NaCl.

In an ionic compound, the number of ions that each ion can touch is referred to as the **coordination number**. It is stated as "(cation)(anion) is (coordination number of cation):(coordination number of anion) coordinated".

!!! example
    In the diagram above, each sodium ion touches six chloride ions, and each chloride ion touches six sodium ions. Therefore, "NaCl is 6:6 coordinated".

## 4.2 - Covalent bonding

A covalent bond is the electrostatic attraction between pairs of valence electrons and nuclei. This causes atoms to "share" electrons instead of gaining or losing them. Covalent bonds form molecules, which in turn form molecular compounds (not covalent compounds).

<img src="/resources/images/covalent-bond.png" width=700>(Source: Kognity)</img>

Whether a covalent bond is **pure** or **polar** indicates how evenly the shared electrons are shared between the atoms.

 - A pure covalent bond has both nuclei attracting the valence electrons fairly evenly, so the difference in electronegativity (ΔEN) is low.
 - A polar covalent bond has both nuclei attracting the valence electrons unevenly, so the ΔEN is high.

Sometimes, one atom in a covalent bond may contribute both electrons in a shared pair. This bond is called a **dative** bond, and is represented in Lewis structures as a double bond. Dative covalent bonds may be used to form bonds when a conventional single or double bond is infeasible, such as in **ozone**.

### Bonding capacity

The **bonding capacity** of a non-metal describes the number of covalent bonds it can form.

## 4.3 - Covalent structures

### Formal charge

There may be several correct ways to draw covalent bonds in Lewis structures and dot diagrams. Solving for the **formal charge** of each atom involved in a covalent bond can help identify the **best** structure to construct. The formal charge of an atom in a covalent bond represents the charge that that atom has. The sum of all formal charges in a covalently bonded compound is equal to the charge of the overall compound. **The element with the lowest electronegativity is almost always in the centre.**

The formal charge of an atom can be calculated using the following equation:
$$\text{Formal charge} = \text{# of valence electrons of element} - \text{# of unpaired electrons} - \text{# of covalent bonds}$$

To find the best structure for a covalently bonded compound, the **absolute value** of the formal charge of all atoms in that compound should be **minimised**. Positively charged atoms will even accept **dative covalent bonds** from other atoms with negative formal charges.

!!! warning
    Some elements want formal charges of zero so much that they break the octet rule. These elements are $\text{P, S, Cl, Br, I, and Xe}$.

### Resonance structures

Even when considering formal charges, there may still be multiple best Lewis structures when molecules or polyatomic ions contain double or triple bonds. These equivalent structures are known as resonance structures, and the number of possible resonance structures is equal to the number of different positions for the double/triple bond. Double-sided arrows are used to show that the forms are resonant.

<img src="/resources/images/resonance-structure.png" width=700>(Source: Kognity)</img>

The resonance structures of a compound show that none of the models is truly correct but instead the actual structure is somewhere **in between all of them**, and is **not** "flipping" between the various resonance structures.

!!! warning
    Molecules such as $\text{SO}_2$ have resonance structures as the possible naive structures prior to involving formal charges are *not* considered to be resonant.

The **resonance-hybrid** structure shows that the actual strength of all three bonds is equal and somewhere between a single and double bond.

<img src="/resources/images/carbonate-delocalised.png" width=400>(Source: Wikipedia)</img>

### Exceptions to the octet rule

Atoms such as boron and beryllium ($\text{B}$ and $\text{Be}$) may form **incomplete octets** (less than 8 electrons) in their valence shell due to their status as **small metalloids** that form covalent bonds. In total, boron can sometimes need only 6 electrons while beryllium may have only 4 in their valence shells.

<img src="/resources/images/bb-octet-exceptions.png" width=700>(Source: Kognity)</img>

!!! example
    $\text{BeCl}_2$ and $\text{BCl}_3$ exist.

Some elements in period 3 and beyond follow the formal charge exception above and may form **expanded octets** (more than 8 electrons and up to 12) in their valence shell. These include the aforementioned $\text{P, S, Cl, Br, I, Xe}$, as well as metalloids.

**Free radicals** are molecules that end up with an odd number of electrons in their valence shell and are *very* reactive. Because one electron can never pair up with another, it remains forever alone.

??? example
    $\text{NO}_2$ is a free radical as one of nitrogen's atoms cannot pair with anything even after the formation of a dative covalent bond from oxygen.

### Factors affecting bond strength

The strength of a bond is determined by the amount of energy required to break that bond (**bond energy**).

The length of a bond (**bond length**) has an inverse relationship with the strength of that bond, as the attraction of electrons to nuclei decreases with distance.

Multiple (double/triple) bonds are shorter than single bonds (a higher **bond order**) and are therefore stronger.

## 4.4 - Intermolecular forces

## 4.5 - Metallic bonding

## 11.1 - Uncertainties and errors in measurement and results

Please see [SL Physics#Uncertainties and errors](/sph3u7/#12-uncertainties-and-errors) for more information.

## 11.2 - Graphical techniques

When plotting a graph:

 - plot the independent variable on the horizontal axis and the dependent variable on the vertical axis
 - label the axes, ensuring that the labels include units
 - choose an appropriate scale for each axis
 - give the graph an appropriate title at the **bottom** in **title case**
 - draw a line of best fit
 - include all uncertainties in the form of error bars
	- if the error bars are too small to see, it should be noted explanation below

### Titles

The title of a graph should clearly indicate what the graph represents under what conditions in **title case**, so that any onlooker should be able to identify the experiment. It should not include "vs." Any legends present should be located under the graph.

??? example
    "Effect of Cat Deaths on Suicides in New Zealand"

### Error bars

Please see [SL Physics#Error bars](/sph3u7/#error-bars) for more information.

### Line of best fit

Please see [SL Physics#Uncertainty of gradient and intercepts](/sph3u7/#uncertainty-of-gradient-and-intercepts) for more information.

## 11.3 - Spectroscopic identification of organic compounds

## Designing a scientific investigation

### Scope

The scope of an experiment goes at the very beginning of it. It includes a general introduction to the topic of investigation as well as personal interest.

### Research question

The research question of an experiment is a hyper-focused and specific question related to the topic. It contains and asks about the effect of an **independent variable** on a **dependent variable**.

### Background information and hypothesis

!!! note
    This section can instead be placed immediately before the research question depending on the experiment.

In this section, scientific theories are provided to help the reader understand the rationale of the question, the design of the experiment, and data processing measures. If any theoretical/literature values are used, they should be introduced here.

A hypothesis consists of a justified prediction of the expected outcome and should be integrated with any background information.

### Variables

!!! definition
    - The **independent** variable is the variable that is explicitly changed to attempt to affect the dependent variable.
    - The **dependent** variable is the variable that is directly monitored and measured in the experiment and is expected to change if the independent variable changes.
    - **Controlled** variables (also known as "control variables") are variables that should be kept constant so they do not affect the dependent variable.

The independent variable, dependent variable, and any controlled variables should be listed under this section.

### Materials

A list of materials and equipment should be listed here, as well as their precision. If a controlled variable needs to be measured, any instruments that would be used to do so should also be listed here.

### Procedure

A clear, detailed, and concise set of instructions written in *past tense* should be placed in this section as either a numbered list or descriptive paragraph. To reduce confusion, if a numbered list is used, referring directly to numbers should be avoided, and referring to numbers recursively must *never* happen. A procedure must include:

 - a clear, titled, labelled, and annotated diagram
 - instructions for recording data (including for controlled variables)

If necessary, a "setup" section can be added as preparatory steps should not be listed in the main procedure.

### Data collection

Data should be collected in an organised and titled table that should be prepared before the experiment. The data table must include:

 - units with uncertainty, typically in the table header
 - *qualitative* data (quantitative data can be optional in some experiments)
 - repeated data/controlled variables, typically in the title
 - any relevant information should be listed under the title

Only **raw data** prior to any processing or calculations, with the exception of averages, should be present in the data table.

A data table should be as concise as possible, and redundancy should be minimised. In that vein, trial numbers should *not* be recorded unless that data is relevant.

!!! example
    **Table 1: Effect of Fat Content on Sugar Content in Ice Cream**
    
    | Fat Content (g ± 0.1 g) | Sugar Content (g ± 0.1 g) | Notes |
    | --- | --- | --- |
    | 2.0 | 5.1 | - strawberry ice cream |
    | 0.1 | 2.3 | - mint chocolate chip ice cream |

Whenever possible, data tables should *not* span multiple pages. If that is unavoidable, a new title with "…continued" and new column headers must be present at the top of each new page.

### Data processing

A single sample calculation showing all steps should be present and clearly explained. The rest of the data can be processed without describing any steps. A **single** graph may be included if needed.

Some general rules include:

 - units and uncertainties must be present in all calculations
 - simple operations such as averages and conversions (e.g., g to kg) do not need to be explained
 - the graph, if any, should span at least half of the page (ideally the full page) and should directly answer the research question

A final, reorganised, and processed data table should be present here, showing only relevant information.

### Conclusion and evaluation

This section should be free of any new background information or calculations. It should, in sequence:

 - summarise the results of the experiment without connecting it to the hypothesis
 - identify whether the results of the experiment agree or disagree with the hypothesis
 - evaluate 3–5 systematic errors (usually) present in the experiment, both in the procedure and in data collection/processing, in **decreasing** order of impact to the experiment

The evaluation of systematic errors should include:

 - a description of the error
 - how the error affected the data
 - how the error affected the final result
 - how the error can be remedied with available school resources

## Resources

 - [IB Chemistry Data Booklet](/resources/g11/ib-chemistry-data-booklet.pdf)
 - [IB HL Chemistry Syllabus](/resources/g11/ib-chemistry-syllabus.pdf)
 - [Significant Figures/Digits](/resources/g11/chemistry-sig-figs.pdf)
 - [Error Analysis and Significant Figures (long)](/resources/g11/error-analysis-sig-figs.pdf)
 - [General Guidelines for Writing a Formal Laboratory Report](/resources/g11/lab-report-guidelines.pdf)
 - [Designing an IB Investigation](/resources/g11/designing-investigation.pdf)

